@@ -5,6 +5,7 @@
 
 import datetime
 import gzip
+import os
 from base64 import b64decode
 from unittest import TestCase, mock
 
@@ -22,12 +23,18 @@ from taskgraph.parameters import (
 
 from .mockedopen import MockedOpen
 
+project_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
+
+with open(os.path.join(project_dir, "version.txt")) as f:
+    version = f.read().rstrip()
+
 
 class TestParameters(TestCase):
 
     vals = {
         "base_repository": "repository",
         "build_date": 0,
+        "build_number": 1,
         "do_not_optimize": [],
         "existing_tasks": {},
         "filters": ["target_tasks_method"],
@@ -37,6 +44,7 @@ class TestParameters(TestCase):
         "head_tag": "",
         "level": "3",
         "moz_build_date": "20191008095500",
+        "next_version": None,
         "optimize_target_tasks": True,
         "owner": "nobody@mozilla.com",
         "project": "project",
@@ -45,6 +53,7 @@ class TestParameters(TestCase):
         "repository_type": "hg",
         "target_tasks_method": "default",
         "tasks_for": "github-push",
+        "version": version,
     }
 
     def test_Parameters_immutable(self):
